#!/usr/bin/env python
#
# This file is part of python-rhev. python-rhev is free software that is
# made available under the MIT license. Consult the file "LICENSE" that
# is distributed together with this file for the exact licensing terms.
#
# python-rhev is copyright (c) 2010-2011 by the python-rhev authors. See
# the file "AUTHORS" for a complete overview.

import os
import sys

from rhev import *
import common


parser = common.create_parser(usage='%prog [options] <name>',
                              description='create a VM using the SDK')
parser.add_option('-m', '--memory', type='int', help='memory size in MB')
parser.add_option('-D', '--disk', type='int', help='disk size in GB')
parser.add_option('-c', '--cluster', help='the cluster to add the VM to')
parser.add_option('-t', '--template', help='base the VM off this template')
parser.add_option('-N', '--network', help='the network to connect to')
parser.set_default('cluster', 'Default')
parser.set_default('template', 'Blank')
parser.set_default('memory', 512)
parser.set_default('disk', 8)
parser.set_default('network', 'rhevm')

opts, args = common.parse_args()

if len(args) != 1:
    common.print_help()
    sys.exit(1)

api = common.connect()

cluster = api.get(schema.Cluster, name=opts.cluster)
if cluster is None:
    sys.stderr.write('Error: cluster not found: %s\n' % opts.cluster)
    sys.exit(1)
datacenter = api.get(schema.DataCenter, id=cluster.data_center.id)
if datacenter is None:
    sys.stderr.write('Error: datacenter not found: %s\n' % cluster.data_center.id)
    sys.exit(1)
storagedomain = api.get(schema.StorageDomain, base=datacenter,
                        filter={'type': 'data'})
if storagedomain is None:
    sys.stderr.write('Error: could not find data domain')
    sys.exit(1)
template = api.get(schema.Template, name=opts.template)
if template is None:
    sys.stderr.write('Error: template not found: %s\n' % opts.template)
    sys.exit(1)
network = api.get(schema.Network, base=cluster,
                        filter={'name': opts.network})
if network is None:
    sys.stderr.write('Error: network not found: %s\n' % opts.network)
    sys.exit(1)

vm = schema.new(schema.VM, name=args[0])
vm.memory = opts.memory * 1024**2
vm.cluster = schema.ref(cluster)
vm.template = schema.ref(template)
vm = api.create(vm)

nic = schema.new(schema.NIC)
nic.name = 'eth0'
nic.type = 'virtio'
nic.network = schema.ref(network)
api.create(nic, base=vm)

disk = schema.new(schema.Disk)
disk.size = opts.disk * 1024**3
disk.format = 'cow'
disk.sparse = True
disk.interface = 'virtio'
disk.storage_domains = schema.new(schema.StorageDomains)
disk.storage_domains.storage_domain = [schema.ref(storagedomain)]

api.create(disk, base=vm)

print 'Created VM: "%s", with %dMB RAM, %dGB disk and 1 NIC' % \
        (args[0], opts.memory, opts.disk)
